@@ -14,7 +14,10 @@ def read_from_jsonl(filename: str) -> List[Dict]:
         return [json.loads(line) for line in input_file]
 
 
-def requires_dependencies(dependencies: Union[str, List[str]], extras: Optional[str] = None):
+def requires_dependencies(
+    dependencies: Union[str, List[str]],
+    extras: Optional[str] = None,
+):
     if isinstance(dependencies, str):
         dependencies = [dependencies]
 
@@ -29,10 +32,12 @@ def requires_dependencies(dependencies: Union[str, List[str]], extras: Optional[
                     missing_deps.append(dep)
             if len(missing_deps) > 0:
                 raise ImportError(
-                    f"Following dependencies are missing: {', '.join(missing_deps)}."
-                    + f"Please install them using `pip install unstructured[{extras}]`."
-                    if extras
-                    else f"Please install them using `pip install {' '.join(missing_deps)}`.",
+                    f"Following dependencies are missing: {', '.join(missing_deps)}. "
+                    + (
+                        f"Please install them using `pip install unstructured[{extras}]`."
+                        if extras
+                        else f"Please install them using `pip install {' '.join(missing_deps)}`."
+                    ),
                 )
             return func(*args, **kwargs)
 
